@@ -28,7 +28,7 @@
 #' @export
 cartesian_to_polar <- function(cartesian, anchor = c(0 , 0, 0), digits = NULL) {
 
-  if(is.numeric(anchor) == FALSE | length(anchor) != 3) {
+  if (!is.numeric(anchor) || length(anchor) != 3) {
     stop("Anchor needs to be a numeric vector of length 3 representing X, Y, and Z")
   }
 
